==> cargo-binstall-1.15.10-1.src.tar.gz: cargo-binstall-1.15.10/crates/atomic-file-install/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.12](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.11...atomic-file-install-v1.0.12) - 2025-09-06

### Other

- *(deps)* bump the deps group with 2 updates ([#2298](https://github.com/cargo-bins/cargo-binstall/pull/2298))

## [1.0.11](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.10...atomic-file-install-v1.0.11) - 2025-03-19

### Other

- *(deps)* bump windows from 0.60.0 to 0.61.1 in the deps group across 1 directory ([#2097](https://github.com/cargo-bins/cargo-binstall/pull/2097))

## [1.0.10](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.9...atomic-file-install-v1.0.10) - 2025-02-22

### Other

- *(deps)* bump windows from 0.59.0 to 0.60.0 in the deps group across 1 directory (#2063)

## [1.0.9](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.8...atomic-file-install-v1.0.9) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [1.0.8](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.7...atomic-file-install-v1.0.8) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [1.0.7](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.6...atomic-file-install-v1.0.7) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [1.0.6](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.5...atomic-file-install-v1.0.6) - 2024-11-18

### Other

- Upgrade transitive dependencies ([#1969](https://github.com/cargo-bins/cargo-binstall/pull/1969))

==> cargo-binstall-1.15.11-1.src.tar.gz: cargo-binstall-1.15.11/crates/atomic-file-install/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.13](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.12...atomic-file-install-v1.0.13) - 2025-11-05

### Other

- Update documentation link in Cargo.toml ([#2355](https://github.com/cargo-bins/cargo-binstall/pull/2355))

## [1.0.12](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.11...atomic-file-install-v1.0.12) - 2025-09-06

### Other

- *(deps)* bump the deps group with 2 updates ([#2298](https://github.com/cargo-bins/cargo-binstall/pull/2298))

## [1.0.11](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.10...atomic-file-install-v1.0.11) - 2025-03-19

### Other

- *(deps)* bump windows from 0.60.0 to 0.61.1 in the deps group across 1 directory ([#2097](https://github.com/cargo-bins/cargo-binstall/pull/2097))

## [1.0.10](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.9...atomic-file-install-v1.0.10) - 2025-02-22

### Other

- *(deps)* bump windows from 0.59.0 to 0.60.0 in the deps group across 1 directory (#2063)

## [1.0.9](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.8...atomic-file-install-v1.0.9) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [1.0.8](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.7...atomic-file-install-v1.0.8) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [1.0.7](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.6...atomic-file-install-v1.0.7) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [1.0.6](https://github.com/cargo-bins/cargo-binstall/compare/atomic-file-install-v1.0.5...atomic-file-install-v1.0.6) - 2024-11-18

### Other

- Upgrade transitive dependencies ([#1969](https://github.com/cargo-bins/cargo-binstall/pull/1969))
